@@ -23,18 +23,26 @@ use Carp;
 use Time::HiRes qw( usleep );
 use Try::Tiny;
 
-our $VERSION ='0.63';
+use constant {
+    I2C_BCM2708 => 1,
+    I2C_BCM2835 => 2,
+};
+
+our $VERSION ='0.64';
 
 __PACKAGE__->create_accessors( qw ( fh fno address busmode readmode ) );
 
 XSLoader::load('HiPi::Device::I2C', $VERSION) if HiPi::is_raspberry_pi();
 
+my $modvers = ( -e '/sys/module/i2c_bcm2708' ) ? I2C_BCM2708 : I2C_BCM2835;
+
 my $combined_param_path = '/sys/module/i2c_bcm2708/parameters/combined';
 my $baudrate_param_path = '/sys/module/i2c_bcm2708/parameters/baudrate';
 
 sub get_required_module_options {
     my $moduleoptions = [
-        [ qw( i2c_bcm2708 i2c_dev ) ],
+        [ qw( i2c_bcm2708 i2c_dev ) ], # older i2c modules
+        [ qw( i2c_bcm2385 i2c_dev ) ],         # recent i2c modules
     ];
     return $moduleoptions;
 }
@@ -186,17 +194,20 @@ sub bus_read {
 
     # check if we need to change read mode
     my $resetcombined = undef;
-    if ($self->readmode == I2C_READMODE_START_STOP  ) {
-        my $combined = $self->get_combined;
-        if ( $combined ne 'N') {
-            $resetcombined = $combined;
-            $self->set_combined('N');
-        }
-    } elsif($self->readmode == I2C_READMODE_REPEATED_START  ) {
-        my $combined = $self->get_combined;
-        if ( $combined ne 'Y') {
-            $resetcombined = $combined;
-            $self->set_combined('Y');
+    
+    if( $modvers == I2C_BCM2708 ) {
+        if ($self->readmode == I2C_READMODE_START_STOP  ) {
+            my $combined = $self->get_combined;
+            if ( $combined ne 'N') {
+                $resetcombined = $combined;
+                $self->set_combined('N');
+            }
+        } elsif($self->readmode == I2C_READMODE_REPEATED_START  ) {
+            my $combined = $self->get_combined;
+            if ( $combined ne 'Y') {
+                $resetcombined = $combined;
+                $self->set_combined('Y');
+            }
         }
     }
     
