@@ -14,7 +14,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION ='0.63';
+our $VERSION ='0.64';
 
 my ( $btype1, $btype2, $btype3) = ( 1, 2, 3 );
 
@@ -211,7 +211,7 @@ sub _configure {
     $rev =~ s/^\s+//;
     $rev =~ s/\s+$//;
     
-    $israspberry = $_cpuinfostash{Hardware} && $_cpuinfostash{Hardware} =~ /^BCM2708|BCM2709|BCM2710$/;
+    $israspberry = $_cpuinfostash{Hardware} && $_cpuinfostash{Hardware} =~ /^BCM2708|BCM2709|BCM2710|BCM2835$/;
         
     if ( $rev =~ /(beta|unknown|unknownex)$/) {
         my $infokey = exists($_revstash{$rev}) ? $rev : $defaultkey;
